summaryrefslogtreecommitdiff
path: root/build.c
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2002-05-19 18:42:25 +0000
committerjbj <devnull@localhost>2002-05-19 18:42:25 +0000
commit2126e4ad09e175a4356a29ab03756dbbeb8c976f (patch)
treee16e86b43a42c9c7fda695b04189afc1d551661b /build.c
parent38385c8d6323e3695e0b267ab7b2fcffff9f72b3 (diff)
downloadrpm-2126e4ad09e175a4356a29ab03756dbbeb8c976f.tar.gz
rpm-2126e4ad09e175a4356a29ab03756dbbeb8c976f.tar.bz2
rpm-2126e4ad09e175a4356a29ab03756dbbeb8c976f.zip
- Grand Renaming of rpm data types.
CVS patchset: 5439 CVS date: 2002/05/19 18:42:25
Diffstat (limited to 'build.c')
-rw-r--r--build.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/build.c b/build.c
index cb25adfbd..5e2e1d888 100644
--- a/build.c
+++ b/build.c
@@ -7,23 +7,24 @@
#include <rpmcli.h>
#include <rpmbuild.h>
+#include "rpmps.h"
#include "rpmte.h"
#include "rpmts.h"
#include "build.h"
#include "debug.h"
/*@access rpmTransactionSet @*/ /* XXX compared with NULL @*/
/*@access rpmdb @*/ /* XXX compared with NULL @*/
/*@access FD_t @*/ /* XXX compared with NULL @*/
/**
*/
-static int checkSpec(rpmTransactionSet ts, Header h)
+static int checkSpec(rpmts ts, Header h)
/*@globals fileSystem, internalState @*/
/*@modifies ts, h, fileSystem, internalState @*/
{
- rpmProblemSet ps;
+ rpmps ps;
int rc;
if (!headerIsEntry(h, RPMTAG_REQUIRENAME)
@@ -40,7 +41,7 @@ static int checkSpec(rpmTransactionSet ts, Header h)
printDepProblems(stderr, ps);
rc = 1;
}
- ps = rpmProblemSetFree(ps);
+ ps = rpmpsFree(ps);
/* XXX nuke the added package. */
rpmtsClean(ts);
@@ -94,7 +95,7 @@ static int isSpecFile(const char * specfile)
/**
*/
-static int buildForTarget(rpmTransactionSet ts, const char * arg, BTA_t ba)
+static int buildForTarget(rpmts ts, const char * arg, BTA_t ba)
/*@globals rpmGlobalMacroContext,
fileSystem, internalState @*/
/*@modifies ts, rpmGlobalMacroContext,
@@ -288,7 +289,7 @@ exit:
return rc;
}
-int build(rpmTransactionSet ts, const char * arg, BTA_t ba, const char * rcfile)
+int build(rpmts ts, const char * arg, BTA_t ba, const char * rcfile)
{
char *t, *te;
int rc = 0;
@@ -7,23 +7,24 @@
#include "build.h"
#include "debug.h"
-/*@access rpmTransactionSet @*/ /* XXX compared with NULL @*/
+/*@access rpmts @*/ /* XXX compared with NULL @*/
/*@access rpmdb @*/ /* XXX compared with NULL @*/
/*@access FD_t @*/ /* XXX compared with NULL @*/